from django.shortcuts import get_object_or_404, render_to_response
from models import Entry,Comment,Author,sidebar
from django.core.paginator import Paginator
import django.forms
import blog_settings 
from django.conf import settings
from django.contrib.sites.models import Site

current_site = Site.objects.get(id=settings.SITE_ID) #This thing is
                                                     #important for
                                                     #link
                                                     #consistency. Not
                                                     #implemented yet

sidebars = sidebar.objects.all()

class CommentForm(forms.ModelForm):
    class Meta:
        model = Comment
        fields = ('title','author','author_email',
                  'author_web','date','body')


def blog(request):
    entries = Paginator(Entry.objects.all().order_by("-date"),
                        blog_settings.BLOG_INDEX_ENTRIES)


    if request.method == "GET":
        try:
            page=request.GET["p"]

        except:
            page = 1

    entries = entries.page(page)
              
    return render_to_response('blog/blog.html', {
        'site':current_site,
        'entries': entries,
        'sidebars':sidebars,
        })


def entry(request,slug):
    entry = Entry.objects.filter(slug=slug)[0]
    comments = Comment.objects.filter(entry__slug=slug)
    return render_to_response('blog/entry.html',{
        'site':current_site,
        'entry':entry,
        'comments':comments,
        'slug':slug,
        'sidebars':sidebars,
            })

def comment_engine(request,slug):
    entry = Entry.objects.filter(slug=slug)[0]
    comments = Comment.objects.filter(entry__slug=slug)
    # Remember the commit=False option
    if request.method == 'POST':
        commentform = CommentForm(request.POST)
        if commentform.is_valid():
            com=commentform.save(commit=False)
            com.karma = 0
            com.entry = entry
            if 'http' in com.body:
                return render_to_response('blog/comment_engine.html',{
                    'site':current_site,
                    'entry':entry,
                    'comments':comments,
                    'slug':slug,
                    'error':True,
                    'sidebars':sidebars,
                })
            else:
                com.save()
                return render_to_response('blog/comment_engine.html',{
                    'site':current_site,
                    'entry':entry,
                    'comments':comments,
                    'slug':slug,
                    'error':False,
                    'sidebars':sidebars,
                    })
        else:
            return render_to_response('blog/comment_engine.html',{
                'site':current_site,
                'entry':entry,
                'comments':comments,
                'slug':slug,
                'error':True,
                'sidebars':sidebars,
                })


    commentform = CommentForm()
    return render_to_response('blog/comment_engine.html',{
        'site':current_site,
        'commentform':commentform,
        'entry':entry,
        'comments':comments,
        'slug':slug,
        'sidebars':sidebars,
        })


def author(request,auth):
    """
    Entries classified by author
    """
    
    entries = Paginator(Entry.objects.filter(author__name=auth).order_by("-date"),
                        blog_settings.BLOG_INDEX_ENTRIES)


    if request.method == "GET":
        try:
            page=request.GET["p"]

        except:
            page = 1

    entries = entries.page(page)
    
    return render_to_response('blog/blog.html', {
        'site':current_site,
        'entries': entries,
        'sidebars':sidebars,
        })



def category(request,cat):
    """
    Entries classified by category
    """
    entries = Paginator(Entry.objects.filter(category__id=cat).order_by("-date"),
                        blog_settings.BLOG_INDEX_ENTRIES)


    if request.method == "GET":
        try:
            page=request.GET["p"]
            
        except:
            page = 1

    entries = entries.page(page)
    
    return render_to_response('blog/blog.html', {
        'site':current_site,
        'entries': entries,
        'sidebars':sidebars,
            })


def tag(request,tag):
    entries = Entry.objects.filter(tag=tag)
    return render_to_response('blog/list.html', {
        'site':current_site,
        'entries': entries,
        'sidebars':sidebars,
        })


def karma_engine(request,pk,vote):
    comment = Comment.objects.filter(pk=pk)[0]
    pass
